/******************************************************************************
Beispiel:      stopWatch

Beschreibung:  dieses Beispiel zeigt die Darstellung der Zahlen auf dem Display
               Anhand einer Stoppuhr.
******************************************************************************/
#include "arduPi.h"
#include "I2C_4DLED.h"

int main (){
  setup();
  while(1){
    loop();
  }
  return (0);
}
/******************************************************************************
globale Konstanten
******************************************************************************/

// die I2C-Adresse des SAA1064-Chips ergibt sich durch die Belegung der Lötjumper
// J6 bis J9, wobei immer nur ein Jumper gebrückt sein darf.
// J6 gebrückt -> Adresse 0x76
// J7 gebrückt -> Adresse 0x74
// J8 gebrückt -> Adresse 0x72
// J9 gebrückt -> Adresse 0x70 (werkseitig gebrückt)
const uint8_t i2cAddressSAA1064     = 0x70;

// Pinbelegung der Tasten für Start, Stopp und Reset
const uint8_t pinStartButton        = 4;
const uint8_t pinStopButton         = 5;
const uint8_t pinResetButton        = 6;

/******************************************************************************
globale Variablen
******************************************************************************/
// Anzeige, ob Stoppuhr steht (0) oder läuft (1)
uint8_t running = 0;

// vergangen Zeit in 0,1 s Schritten
uint16_t stop_time = 0;

// Flag zur Anzeige, dass der Timerinterrupt aktiviert wurde
volatile uint8_t timerflag = 0;

/******************************************************************************
Funktionen
******************************************************************************/
void setup() 
{
  // I2C-Modul initialisieren
  Wire.begin();
  
  // 4-Digit-LED-Anzeige mit I2C-Adresse des SAA1064 initialisieren
  FourDigitLedDisplay.begin(i2cAddressSAA1064);
  
  // Pins für die Taster als Eingänge setzen
  pinMode(pinStartButton, INPUT);
  pinMode(pinStopButton, INPUT);
  pinMode(pinResetButton, INPUT);
  
  // interne Pullup-Widerstände für die Tastereingänge aktivieren
  digitalWrite(pinStartButton, HIGH);
  digitalWrite(pinStopButton, HIGH);
  digitalWrite(pinResetButton, HIGH);
}

void loop()
{
  // alle 0,1 s die Zeit inkrementieren, die neue Zeit ausgeben und
  // die Taster auswerten.
  delay(100);

    // die Zeit nur erhöhen, wenn die Stoppuhr aktiviert ist
    if(running == 1)
    {
      stop_time++;
    }
    
    // Zeit auf dem Display ausgeben
    FourDigitLedDisplay.writeDecimal(stop_time, 1);
    
    // Stoppuhr laufen lassen, wenn der Start-Taster
    // gedrückt wurde
    if(digitalRead(pinStartButton) == 0)
    {
      running = 1;
    }

    // Stoppuhr anhalten, wenn der Stopp-Taster
    // gedrückt wurde    
    if(digitalRead(pinStopButton) == 0)
    {
      running = 0;
    }
    
    // Stoppuhr anhalten und zurücksetzen, wenn
    // der Reset-Taster gedrückt wurde
    if(digitalRead(pinResetButton) == 0)
    {
      running = 0;
      stop_time = 0;
    }
}
