/******************************************************************************
Beispiel:      configuration

Beschreibung:  dieses Beispiel zeigt die Nutzung der get- und set-Methoden, um
               die Konfiguration des MCP8901 zu ändern bzw. auszulesen.
******************************************************************************/
#include "arduPi.h"
#include "MCP9801.h"

int main (){
  setup();
  while(1){
    loop();
  }
  return (0);
}

/******************************************************************************
globale Konstanten
******************************************************************************/
// beim I2C-4DLED-Board kann die I2C-Adresse über Lötjumper konfiguriert werden
// folgende Adressen ergeben sich aus den verschiedenen Jumperbrücken:
//
// 0: Lötjumper gebrückt (Pin liegt an Masse)
// 1: Lötjumper offen (Pin liegt an Versorgungsspannung)
//
//   J12 (A2)        J11 (A1)        J10 (A0)        Adresse
// ---------------------------------------------------------
//    0               0               0                0x90
//    0               0               1                0x92
//    0               1               0                0x94
//    0               1               1                0x96
//    1               0               0                0x98
//    1               0               1                0x9A
//    1               1               0                0x9C
//    1               1               1                0x9E

const uint8_t i2cAddressMCP9801     = 0x90;

/******************************************************************************
Funktionen
******************************************************************************/
void printConfiguration(void)
{
  int16_t temperature;
  float float_temperature;
  printf("OneShot: %d\r\n",TemperatureSensor.getOneShot());

  printf("ADCResolution: %d\r\n",TemperatureSensor.getADCResolution());

  printf("AlertPolarity: %d\r\n",TemperatureSensor.getAlertPolarity());

  printf("Mode: %d\r\n",TemperatureSensor.getMode());

  printf("Shutdown: %d\r\n",TemperatureSensor.getShutdown());
    
  temperature = TemperatureSensor.getTemperatureHysteresis();
  float_temperature = temperature / 10;
  printf("Hysterese: %0.1f Grad Celsius\r\n",float_temperature);

  
  temperature = TemperatureSensor.getTemperatureLimit();
  float_temperature = temperature / 10;
  
  printf("Limit: %0.1f Grad Celsius\r\n",float_temperature);

  printf("----------------\r\n");
}

void setup() 
{
  // I2C-Modul initialisieren
  Wire.begin();
  
  // Temperatursensor mit I2C-Adresse des MCP9801 initialisieren
  TemperatureSensor.begin(i2cAddressMCP9801);
  
  // Zufallszahlengenerator initialisieren
  srand(analogRead(0));
  
  // Start-Konfiguration ausgeben
  printConfiguration();
  
  // Konfiguration bearbeiten
  printf("Konfiguration wird bearbeitet.\r\n");
  printf("----------------\r\n");
  
  TemperatureSensor.setShutdown(MCP9801::SHUTDOWN_ENABLE);  
  TemperatureSensor.setMode(MCP9801::INTERRUPT_MODE);
  TemperatureSensor.setAlertPolarity(MCP9801::POLARITY_ACTIVE_HIGH);
  TemperatureSensor.setFaultQueue(MCP9801::FAULTQUEUE_8);
  TemperatureSensor.setADCResolution(MCP9801::RESOLUTION_12BIT);
  TemperatureSensor.setOneShot(MCP9801::ONESHOT_ENABLE);

  // die Temperaturen werden auf einen Zufallswert zwischen -100,0°C und
  // +100°C gesetzt, um bei einem Reset sich ändernde Werte zu generieren.
  TemperatureSensor.setTemperatureLimit(rand()%1000-500);
  TemperatureSensor.setTemperatureHysteresis(rand()%1000-500);

  // neue Konfiguration ausgeben
  printConfiguration();
}

void loop()
{
  exit(1);
}
