/******************************************************************************
Beispiel:       oscillationWasHalted

Beschreibung:   Dieses Beispiel zeigt, ob die Oszillation des RTC-Chips angehalten
                wurde oder nicht. Diese Funktion dient dem Mikrocontroller nach 
                dem Start zur Kontrolle, ob die Daten des batteriegepufferten  
                RTC-Chips noch in Ordnung sind und somit übernommen werden können.
                
                Hinweis:
                oscillationWasHalted muss vor begin aufgerufen werden, da bei der 
                Initialisierung des RTC-Chips automatisch das Bit für die angehaltene 
                Oszillation gelöscht wird.
******************************************************************************/
#include "arduPi.h"
#include "TwoWireRTC.h"

int main (){
  setup();
  while(1){
    loop();
  }
  return (0);
}

/******************************************************************************
Funktionen
******************************************************************************/
void setup() 
{
  unsigned char oscillationWasHalted;
  
  Wire.begin();
  
  // Abfrage wiederholen bis das entsprechende Byte ausgelesen werden konnte
  while(RTC.checkIfOscillationWasHalted(&oscillationWasHalted) == 1)
  {}
  
  if(oscillationWasHalted)
    printf("Spannungsversorgung des RTC wurde unterbrochen.\n");
  else
    printf("Spannungsversorgung des RTC wurde nicht unterbrochen.\n");
  
  RTC.begin();
}

void loop() 
{
  // Programm beenden
  exit(1);
}