/*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*/
#include "ADCPi.h"

/*******************************
 *                             *
 * ADCPi Class implementation *
 * --------------------------- *
 *******************************/

/******************
 * Public methods *
 ******************/

//Constructor 
ADCPi::ADCPi()
{
}

//Initiate the ADC library
void ADCPi::begin()
{
  reference = DEFAULT;
  clock_source = CLK_EXTERNAL;
  operation_mode = UNIPOLAR;
  scan_mode = SELECTED_ONLY;
  input_mode = SINGLE_ENDED;
  Wire.begin();
}

//Read ADC Channel
unsigned char ADCPi::analogRead (unsigned char pin)
{
  unsigned char value;
  char temp_data[2];
  
  if(pin > 11)
  {
    printf("Pin not supported!\r\n");
    return 0;
  }
  temp_data[0] = 0x82 | (reference<<4) | (clock_source<<3) | (operation_mode<<2);
  temp_data[1] = (scan_mode<<5) | (pin<<1) | (input_mode<<0);
  
  
  Wire.beginTransmission(0x65); 
  Wire.write(&temp_data[0],2);  
  Wire.endTransmission();
  Wire.requestFrom(0x65, 1);
  value = (byte)Wire.read();
  Wire.endTransmission();
  return value;
}

//Set ADC reference voltage
void ADCPi::analogReference(ref_types_t type)
{
  switch(type)
  {
    case INTERNAL1V1:
    case INTERNAL2V56:
      printf("Reference not supported, default was set!\r\n");
    case DEFAULT:
    default:
      reference = 0;
    break;
    case EXTERNAL:
      reference = 2;
    break;
    case INTERNAL:
      reference = 5;
    break;
  }
}

//Set ADC clock source
void ADCPi::analogClock(clock_types_t clock)
{
  clock_source = clock;
}

//Set ADC operation mode
void ADCPi::analogOperationMode(operation_mode_t mode)
{
  operation_mode = mode;
}

//Set ADC scan mode
void ADCPi::analogScanMode(scan_mode_t mode)
{
  scan_mode = mode;
}

//Set AD input mode
void ADCPi::analogInputMode(input_mode_t mode)
{
  input_mode = mode;
}

ADCPi ADC = ADCPi();