#ifndef _ADCPi_h
#define _ADCPi_h
#include "arduPi.h"

typedef enum 
{
  DEFAULT,      //Die analoge Standardreferenz von 5 Volt
  INTERNAL,     //Die eingebaute Referenz von 4,096 V beim MAX1038
  INTERNAL1V1,  //eine eingebaute 1,1V Referenz (nur beim Arduino Mega verwendbar)
  INTERNAL2V56, //eine eingebaute 2.56V Reference (nur beim Arduino Mega verwendbar)
  EXTERNAL      //Als Referenz wird die Spannung verwendet, die am AREF-Pin ( ausschlielich zwischen 0V und 5V verwenden) anliegt
} ref_types_t;

typedef enum 
{
  CLK_INTERNAL,
  CLK_EXTERNAL
} clock_types_t;

typedef enum 
{
  UNIPOLAR,
  BIPOLAR
} operation_mode_t;

typedef enum 
{
  ZERO_TO_SELECTED,
  SELECTED_EIGHT_TIMES,
  SIX_TO_SELECTED,
  SELECTED_ONLY,
} scan_mode_t;

typedef enum 
{
  PSEUDO_DIFFERTIAL,
  SINGLE_ENDED
} input_mode_t;

class ADCPi
{
  private:
    unsigned char reference;
    clock_types_t clock_source;
    operation_mode_t operation_mode;
    scan_mode_t scan_mode;
    input_mode_t input_mode;
  public:
    ADCPi();
    void begin();
    unsigned char analogRead (unsigned char pin);
    void analogReference(ref_types_t type);
    void analogClock(clock_types_t clock);
    void analogOperationMode(operation_mode_t mode);
    void analogScanMode(scan_mode_t mode);
    void analogInputMode(input_mode_t mode);
};

extern ADCPi ADC;
#endif
