/*--------------------------------------------------------------------------*/ 
/** 
 * \file two_wire_flip_sign.cpp 
 * \brief include the methods for the TWO_WIRE_FLIP_SIGN class 
 * \author eQ-3 Entwicklung GmbH 
 */ 
/*-------------------------------------------------------------------------- 
 * Copyright 2012 eQ-3 Entwicklung GmbH 
 * All Rights Reserved. 
 * 
 * The information contained in this file is confidential property of "eQ-3 
 * Entwicklung GmbH". The use copying, transfer or disclosure is prohibited 
 * except by written agreement with "eQ-3 Entwicklung GmbH". 
 *--------------------------------------------------------------------------*/ 
/** 
 * \addtogroup TWO_WIRE_FLIP_SIGN
 * \{ 
 */ 
/*--------------------------------------------------------------------------*/ 

extern "C" 
{
#include <math.h>
}

#include "arduPi.h"
#include "two_wire_flip_sign.h"

/** 
 * \brief Constructor of the class 
 * 
 * \param nome 
 * \return none
 * 
**/ 
TWO_WIRE_FLIP_SIGN::TWO_WIRE_FLIP_SIGN()
{
}

/** 
 * \brief Set the state of the flip sign without any timer 
 * 
 * \param u8_command The flip direction command for the sign  
 * 
 * \return none 
 * 
**/ 
void TWO_WIRE_FLIP_SIGN::set_state(uint8_t command)
{
  write_data(I2C_FLIP_SIGN_ADDRESS, command, 0, 0, 1);  
}

/** 
 * \brief Set the state of the flip sign without any timer 
 * 
 * \param u8_command The flip direction command for the sign 
 * \param f64_duration Timer value in seconds 
 * 
 * \return none
 * 
**/ 
void TWO_WIRE_FLIP_SIGN::set_state(uint8_t u8_command, float64_t f64_duration)
{  
  uint8_t u8_time1, u8_time0, u8_exponent = 0x00;
  uint16_t u16_timer_value;
  uint32_t u32_duration;
  
  f64_duration = f64_duration * 10;
  
  u32_duration = (uint32_t)f64_duration;
  
  while( u32_duration > 2047 )
  {
    u32_duration >>= 1;
    u8_exponent++;
  }
  
  u16_timer_value = (((uint16_t)u32_duration << 5) | u8_exponent );
  
  u8_time1 = (uint8_t)(u16_timer_value >> 8);
  u8_time0 = (uint8_t)(u16_timer_value & 0xFF);
  
  write_data(I2C_FLIP_SIGN_ADDRESS, u8_command, u8_time1, u8_time0, 3);  
}

/** 
 * \brief Send data via the I2C-Bus  
 * 
 * \param u8_address The bus I2C-address of the device    
 * \param u8_command The flip direction command for the sign
 * \param u8_time1 First part of the timer value 
 * \param u8_time0 Second part of the timer value
 * \param u8_datalength Number of bytes to send   
 * 
 * \return none 
 * 
**/ 
void TWO_WIRE_FLIP_SIGN::write_data(uint8_t u8_address, uint8_t u8_command, uint8_t u8_time1, uint8_t u8_time0, uint8_t u8_datalength)
{
  char data[4];
  data[0] = u8_command;
  data[1] = u8_time1;
  data[2] = u8_time0;
  data[3] = u8_datalength;
  Wire.beginTransmission(u8_address);
  // Wire.write(u8_command);
  // Wire.write(u8_time1);
  // Wire.write(u8_time0);
  // Wire.write(u8_datalength);
  Wire.write(&data[0], 4);
  Wire.endTransmission();
}

/**
Declares an instance of the class TWO_WIRE_FLIP_SIGN
*/
TWO_WIRE_FLIP_SIGN FLIPSIGN = TWO_WIRE_FLIP_SIGN();

/** \}
 * End of file
**/