#ifndef TwoWireRTC_h
#define TwoWireRTC_h

extern "C" 
{
  #include "RS5C372A.h"
}

#include "arduPi.h"
#include "DateTime.h"

/**********************************************************
Definitionen
**********************************************************/

/**********************************************************
Klasse TwoWireRTC
**********************************************************/
class TwoWireRTC
{
  private:
    unsigned char controlRegister1;
    unsigned char controlRegister2;
    // Schreiben bzw. Lesen der Register
    void writeRegister(unsigned char, Register_t, unsigned char*, unsigned char);
    unsigned char readRegister(unsigned char, Register_t, unsigned char, unsigned char*);
    // Konvertierung BCD zu Dezimal bzw. Dezimal zu BCD
    unsigned char decimalToBCD(unsigned char);
    unsigned char BCDToDecimal(unsigned char);

  public:
    TwoWireRTC();
    // Systemstart
    void begin(void);
    unsigned char checkIfOscillationWasHalted(unsigned char *oscillationWasHalted);
    // Zeiteinstellung
    void setTime(DateTime *dateTime);
    unsigned char getTime(DateTime *dateTime);
    // Alarm
    void setAlarmTime(Alarm_t alarm, AlarmWeekdays_t weekdays, unsigned char hour, unsigned char minute);
    unsigned char getAlarmTime(Alarm_t alarm, AlarmWeekdays_t *weekdays, unsigned char *hour, unsigned char *minute);
    void activateAlarm(Alarm_t alarm);
    void deactivateAlarm(Alarm_t alarm);
    void resetAlarm(Alarm_t alarm);
    // Kalibrierung
    void setTimeTrimming(char newTimeTrimmingValue);
    unsigned char getTimeTrimming(char *timeTrimmingValue);
    // periodischer Interrupt
    void setPeriodicInterrupt(PeriodicInterruptSelection_t periodicInterruptSelection);
    void resetPeriodicInterrupt(void);
};

extern TwoWireRTC RTC;

#endif /* TwoWireRTC_h */